pub fn mutate_config_document<T, F>(path: &Path, mutate: F) -> Result<T>where F: FnOnce(&mut DocumentMut) -> Result<T>,
Parse the latest document under the shared write lock, apply mutate, and atomically persist only the resulting delta.
mutate